#
# spec file for package jackson-bom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jackson-bom
Version:        2.17.3
Release:        1.2
Summary:        Bill of materials POM for Jackson projects
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/FasterXML/jackson-bom
Source0:        https://github.com/FasterXML/jackson-bom/archive/%{name}-%{version}.tar.gz
# Upstream chooses not to include licenses with their pom only projects:
# https://github.com/FasterXML/jackson-parent/issues/1
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt
BuildRequires:  javapackages-local
BuildRequires:  maven-local
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(com.fasterxml.jackson:jackson-parent:pom:)
BuildArch:      noarch

%description
A "bill of materials" POM for Jackson dependencies.

%prep
%setup -q -n %{name}-%{name}-%{version}

cp -p %{SOURCE1} LICENSE
sed -i 's/\r//' LICENSE

# Disable plugins not needed during RPM builds
%pom_remove_plugin ":maven-enforcer-plugin" base
%pom_remove_plugin ":nexus-staging-maven-plugin" base
%pom_remove_dep -r :junit-bom

%build

%install
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
install -pm 0644 base/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/jackson-base.pom
%add_maven_depmap %{name}/%{name}.pom
%add_maven_depmap %{name}/jackson-base.pom

%files -f .mfiles
%doc README.md
%license LICENSE

%changelog
* Wed Nov  6 2024 Fridrich Strba <fstrba@suse.com>
- Update to 2.17.3
  * No changes since 2.17.2
* Wed Aug  7 2024 Fridrich Strba <fstrba@suse.com>
- Update to 2.17.2
  * No changes since 2.17.1
* Mon May 20 2024 Gus Kenion <gus.kenion@suse.com>
- Update to 2.17.1
  * No changes since 2.17.0
- Includes changes from 2.17.0
  * Add `jackson-jr-extension-javatime`
  * Add managed dependency to JUnit5
- Remove unused JUnit5 dependency
* Fri Mar  8 2024 Gus Kenion <gkenion@suse.com>
- Update to version 2.16.1
  * 2.16.1 (24-Dec-2023)
    + No changes since 2.16.0
  * 2.16.0 (15-Nov-2023)
    + Add dependency for jackson-module-android-record. This new
    module offers support for Record type on Android platform,
    where Java records are supported through "de-sugaring".
* Mon Aug 21 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 2.15.2
  * 2.15.2 (30-May-2023)
    + No changes since 2.15.1
  * 2.15.1 (16-May-2023)
    + #63: Update 'de.jjohannes:gradle-module-metadata-maven-plugin'
    to 0.4.0
    + Add override for 'version.plugin.moditect' to be '1.0.0.Final'
    until upgraded in 'oss-parent'/51
  * 2.15.0 (23-Apr-2023)
    + #56: Change defaults for Felix OSGi Bundle plug-in to fix
    timestamps for Reproducible Builds
    + Add version for 'jackson-datatype-hibernate6'
    + Add version for 'jackson-module-jsonSchema-jakarta'
  * 2.14.0 (05-Nov-2022)
    + #52: Gradle reports incorrect jackson-bom dependency version
* Wed Jun 15 2022 Fridrich Strba <fstrba@suse.com>
- Update to version 2.13.3
  * 2.13.3 (14-May-2022)
    + No changes since 2.13.2
  * 2.13.2 (06-Mar-2022)
    + #46: 'module-info.java' is in 'META-INF/versions/11' instead
    of 'META-INF/versions/9'
  * 2.13.1 (19-Dec-2021)
    + No changes since 2.13.0
* Wed Oct 20 2021 Fridrich Strba <fstrba@suse.com>
- Update to version 2.13.0
  * 2.13.0 (30-Sep-2021)
    + #39: Configure moditect plugin with
    '<jvmVersion>11</jvmVersion>'
    + #43: jackson-bom manages the version of 'junit:junit'
    + [datatype-hibernate#39]: Drop 'jackson-datatype-hibernate3'
    (support for Hibernate 3.x datatypes)
    + [jackson-jarx-providers#146] due to addition of new Jakarta
    artifacts - (Jakarta-JSONP, Jakarta-xmlbind-annotations,
    Jakarta-rs-providers) - removed "jakarta" classifier variants
    of JAXB/JSON-P/JAX-RS modules
  * 2.12.3 (12-Apr-2021)
    + Add version for 'jackson-datatype-jakarta-jsonp' module
    (introduced after 2.12.2)
    + Add (beta) version for 'jackson-dataformat-toml'
  * 2.12.2 (03-Mar-2021)
    + #40: Jakarta 9 artifact versions are missing from jackson-bom
  * 2.12.0 (29-Nov-2020)
    + Add another execution of 'maven-replacer-plugin' for
    "prepare-package" phase
  to help with IDE import.
    + Add default settings for 'gradle-module-metadata-maven-plugin'
    (gradle metadata)
    + Add default settings for 'build-helper-maven-plugin'
    (LICENSE inclusion)
    + Drop 'jackson-module-scala_2.10' entry (not released for
    Jackson 2.12 or later)
  * 2.11.2
    + Add override for 'version.plugin.bundle' (for 5.1.1) to help
    build on JDK 15+
* Mon Jan 25 2021 Fridrich Strba <fstrba@suse.com>
- Update to version 2.10.5
  * Add missing version for jackson-datatype-eclipse-collections
* Thu Mar 26 2020 Fridrich Strba <fstrba@suse.com>
- Update to version 2.10.3
* Tue Jan  7 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to version 2.10.2
* Wed Nov 20 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to version 2.10.1
* Wed May  8 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jackson-bom poms version 2.9.4
